import Image from "next/image";

import { Search, ShoppingCart } from "lucide-react";

import { Button } from "@/components/ui/button";
import { Link, Locale } from "@/i18n/routing";

import MobileNavigation2 from "../header-2/mobile-navigation-2";

export default function MiddleHeader({ locale }: { locale: Locale }) {
  return (
    <div className="min-h-[20px] w-full lg:min-h-[102px]">
      <div className="container mx-auto flex items-center justify-between">
        <Link href="/" className="mx-2 flex items-center gap-2">
          <Image
            src="/logo.png"
            alt="Bin Taleb Logo"
            width={150}
            height={50}
            className="h-auto w-auto"
          />
        </Link>
        <div className="flex items-center gap-4">
          <div className="hidden items-center gap-4 sm:flex">
            <Button className="rounded-none bg-custom-primary-accent px-[18px] py-2 text-[12px] leading-[24px] text-custom-background-light">
              {locale === "ar" ? "تواصل معنا" : "Contact Us"}
            </Button>
            <Button
              variant="outline"
              className="rounded-none bg-white px-[18px] py-2 text-[12px] leading-[24px] text-[#10131C]"
              style={{ border: "1px solid #DEDEDE" }}
            >
              {locale === "ar" ? "برنامج المحاكاة" : "Simulation Program"}
            </Button>
          </div>

          <Link
            href="/cart"
            className="relative flex h-10 w-10 items-center justify-center rounded-full bg-custom-primary-accent p-2 text-white hover:bg-custom-primary/90"
            aria-label="Shopping cart"
          >
            <ShoppingCart className="size-5" />
            <span className="absolute -right-1 -top-1 flex size-5 items-center justify-center rounded-full bg-custom-primary text-xs font-bold">
              0
            </span>
          </Link>
          <button
            className="flex h-10 w-10 items-center justify-center rounded-full bg-custom-primary-accent p-2 text-white hover:bg-custom-secondary/90"
            aria-label="Search"
          >
            <Search className="size-5" />
          </button>
          <MobileNavigation2 locale={locale} />
        </div>
      </div>
    </div>
  );
}
